import { DynamoDB } from "aws-sdk";
import DocumentClient = DynamoDB.DocumentClient;
/**
 * Helper for obtaining dynamo responses as async generator.
 */
export default class {
    private documentClient;
    /**
     * @param {DocumentClient} documentClient
     */
    constructor(documentClient: DocumentClient);
    /**
     * Returns items generator for dynamo scan request
     * @param {DocumentClient.ScanInput} input
     * @return {AsyncGenerator<DynamoDB.DocumentClient.AttributeMap>}
     */
    scan(input: DocumentClient.ScanInput): AsyncGenerator<DynamoDB.DocumentClient.AttributeMap>;
    /**
     * Returns items generator for dynamo query request
     * @param {DocumentClient.QueryInput} input
     * @return {AsyncGenerator<DynamoDB.DocumentClient.AttributeMap>}
     */
    query(input: DocumentClient.QueryInput): AsyncGenerator<DynamoDB.DocumentClient.AttributeMap>;
    /**
     * Returns scan responses generator for dynamo scan requests
     * @param input DynamoDB.DocumentClient.ScanInput
     * @return {AsyncGenerator<DynamoDB.DocumentClient.ScanOutput>}
     */
    scanResponses(input: DocumentClient.ScanInput): AsyncGenerator<DynamoDB.DocumentClient.ScanOutput>;
    /**
     * Returns query responses generator for dynamo query requests
     * @param input DynamoDB.DocumentClient.QueryInput
     * @return {AsyncGenerator<DynamoDB.DocumentClient.QueryOutput>}
     */
    queryResponses(input: DocumentClient.QueryInput): AsyncGenerator<DynamoDB.DocumentClient.QueryOutput>;
}
