"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Helper for obtaining dynamo responses as async generator.
 */
class default_1 {
    documentClient;
    /**
     * @param {DocumentClient} documentClient
     */
    constructor(documentClient) {
        this.documentClient = documentClient;
    }
    /**
     * Returns items generator for dynamo scan request
     * @param {DocumentClient.ScanInput} input
     * @return {AsyncGenerator<DynamoDB.DocumentClient.AttributeMap>}
     */
    async *scan(input) {
        for await (const response of this.scanResponses(input)) {
            for (const item of response.Items) {
                yield item;
            }
        }
    }
    /**
     * Returns items generator for dynamo query request
     * @param {DocumentClient.QueryInput} input
     * @return {AsyncGenerator<DynamoDB.DocumentClient.AttributeMap>}
     */
    async *query(input) {
        for await (const response of this.queryResponses(input)) {
            for (const item of response.Items) {
                yield item;
            }
        }
    }
    /**
     * Returns scan responses generator for dynamo scan requests
     * @param input DynamoDB.DocumentClient.ScanInput
     * @return {AsyncGenerator<DynamoDB.DocumentClient.ScanOutput>}
     */
    async *scanResponses(input) {
        let response;
        do {
            response = await this.documentClient.scan(Object.assign(input, { ExclusiveStartKey: response?.LastEvaluatedKey })).promise();
            yield response;
        } while (response.LastEvaluatedKey !== undefined);
    }
    /**
     * Returns query responses generator for dynamo query requests
     * @param input DynamoDB.DocumentClient.QueryInput
     * @return {AsyncGenerator<DynamoDB.DocumentClient.QueryOutput>}
     */
    async *queryResponses(input) {
        let response;
        do {
            response = await this.documentClient.query(Object.assign(input, { ExclusiveStartKey: response?.LastEvaluatedKey })).promise();
            yield response;
        } while (response.LastEvaluatedKey !== undefined);
    }
}
exports.default = default_1;
//# sourceMappingURL=dynamo-iterator.factory.js.map