"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const mocha_1 = require("mocha");
const dynamo_iterator_factory_1 = require("./dynamo-iterator.factory");
const fake_document_client_class_1 = require("./fake.document-client.class");
(0, mocha_1.describe)("Having a iterator document client", () => {
    let dynamoGeneratorFactory;
    let fakeDocumentClient;
    (0, mocha_1.beforeEach)(() => {
        fakeDocumentClient = new fake_document_client_class_1.default();
        dynamoGeneratorFactory = new dynamo_iterator_factory_1.default(fakeDocumentClient);
    });
    (0, mocha_1.describe)("and document client having 4 items", () => {
        const itemsAmount = 4;
        (0, mocha_1.beforeEach)(() => {
            for (let i = 0; i < itemsAmount; i++) {
                fakeDocumentClient.list.push({ value: buildItem(i) });
            }
        });
        (0, mocha_1.describe)("and asking to scan", () => {
            let generator;
            (0, mocha_1.beforeEach)(() => generator = dynamoGeneratorFactory.scan({ TableName: "tableName" }));
            (0, mocha_1.describe)("and iterating the response", () => {
                let items = [];
                (0, mocha_1.beforeEach)(async () => {
                    items = [];
                    for await (const item of generator) {
                        items.push(item);
                    }
                });
                (0, mocha_1.it)("should iterate all items", () => (0, chai_1.expect)(items).to.be.length(itemsAmount));
                (0, mocha_1.it)("should iterate in correct order", () => {
                    for (let i = 0; i < itemsAmount; i++) {
                        (0, chai_1.expect)(items[i].id).to.be.eq(buildId(i));
                    }
                });
            });
        });
    });
    (0, mocha_1.describe)("and document client having 5 items", () => {
        const itemsAmount = 5;
        (0, mocha_1.beforeEach)(() => {
            for (let i = 0; i < itemsAmount; i++) {
                fakeDocumentClient.list.push({ value: buildItem(i) });
            }
        });
        (0, mocha_1.describe)("and asking to scan", () => {
            let generator;
            (0, mocha_1.beforeEach)(() => generator = dynamoGeneratorFactory.scan({ TableName: "tableName" }));
            (0, mocha_1.describe)("and iterating the response", () => {
                let items = [];
                (0, mocha_1.beforeEach)(async () => {
                    items = [];
                    for await (const item of generator) {
                        items.push(item);
                    }
                });
                (0, mocha_1.it)("should iterate all items", () => (0, chai_1.expect)(items).to.be.length(itemsAmount));
                (0, mocha_1.it)("should iterate in correct order", () => {
                    for (let i = 0; i < itemsAmount; i++) {
                        (0, chai_1.expect)(items[i].id).to.be.eq(buildId(i));
                    }
                });
            });
            (0, mocha_1.describe)("and iterating with next method", () => {
                let items = [];
                (0, mocha_1.beforeEach)(async () => {
                    items = [];
                    for await (const item of generator) {
                        items.push(item);
                    }
                });
                (0, mocha_1.it)("should iterate all items", () => (0, chai_1.expect)(items).to.be.length(itemsAmount));
                (0, mocha_1.it)("should iterate in correct order", () => {
                    for (let i = 0; i < itemsAmount; i++) {
                        (0, chai_1.expect)(items[i].id).to.be.eq(buildId(i));
                    }
                });
            });
        });
        (0, mocha_1.describe)("and asking to query", () => {
            let generator;
            (0, mocha_1.beforeEach)(() => generator = dynamoGeneratorFactory.query({ TableName: "tableName" }));
            (0, mocha_1.describe)("and iterating the response", () => {
                let items;
                (0, mocha_1.beforeEach)(async () => {
                    items = [];
                    for await (const item of generator) {
                        items.push(item);
                    }
                });
                (0, mocha_1.it)("should iterate all items", () => (0, chai_1.expect)(items).to.be.length(5));
            });
        });
        (0, mocha_1.describe)("and there are no items in the collection", () => {
            (0, mocha_1.beforeEach)(() => fakeDocumentClient.list = []);
            (0, mocha_1.describe)("and asking to query", () => {
                let generator;
                (0, mocha_1.beforeEach)(() => generator = dynamoGeneratorFactory.query({ TableName: "tableName" }));
                (0, mocha_1.it)("should no iterate", async () => {
                    // eslint-disable-next-line @typescript-eslint/no-unused-vars
                    for await (const item of generator) {
                        chai_1.expect.fail("should not iterate");
                    }
                });
            });
        });
        (0, mocha_1.describe)("and last items batch is empty", () => {
            (0, mocha_1.beforeEach)(() => fakeDocumentClient.list.push({ value: buildItem(5), matches: false }, { value: buildItem(6), matches: false }, { value: buildItem(7), matches: false }));
            (0, mocha_1.describe)("and asking to scan", () => {
                let generator;
                (0, mocha_1.beforeEach)(() => generator = dynamoGeneratorFactory.scan({ TableName: "tableName" }));
                (0, mocha_1.describe)("and iterating the response", () => {
                    let items = [];
                    (0, mocha_1.beforeEach)(async () => {
                        items = [];
                        for await (const item of generator) {
                            items.push(item);
                        }
                    });
                    (0, mocha_1.it)("should iterate all items", () => (0, chai_1.expect)(items).to.be.length(itemsAmount));
                });
            });
        });
        (0, mocha_1.describe)("and middle items batch is empty", () => {
            (0, mocha_1.beforeEach)(() => fakeDocumentClient.list = [
                { value: buildItem(0) },
                { value: buildItem(1) },
                { value: buildItem(2), matches: false },
                { value: buildItem(3), matches: false },
                { value: buildItem(4), matches: false },
                { value: buildItem(5) },
            ]);
            (0, mocha_1.describe)("and asking to scan", () => {
                let generator;
                (0, mocha_1.beforeEach)(() => generator = dynamoGeneratorFactory.scan({ TableName: "tableName" }));
                (0, mocha_1.describe)("and iterating the response", () => {
                    let items = [];
                    (0, mocha_1.beforeEach)(async () => {
                        items = [];
                        for await (const item of generator) {
                            items.push(item);
                        }
                    });
                    (0, mocha_1.it)("should iterate all items", () => (0, chai_1.expect)(items).to.be.length(3));
                });
            });
        });
    });
    function buildItem(i) {
        return { id: buildId(i) };
    }
    function buildId(i) {
        return `item${i}Id`;
    }
});
//# sourceMappingURL=dynamo-iterator.factory.test.js.map